@@ -163,12 +163,12 @@ static void nv_p2p_free_dma_mapping(
 
     os_mem_set(peer_nvl, 0, sizeof(nv_linux_state_t));
 
-    peer_nvl->dev = dma_mapping->dev;
+    peer_nvl->pci_dev = dma_mapping->pci_dev;
 
     peer_nv = NV_STATE_PTR(peer_nvl);
 
     peer_nv->dma_addressable_start = 0;
-    peer_nv->dma_addressable_limit = peer_nvl->dev->dma_mask;
+    peer_nv->dma_addressable_limit = peer_nvl->pci_dev->dma_mask;
     peer_nv->os_state = peer_nvl;
 
     page_size = nvidia_p2p_page_size_mappings[dma_mapping->page_size_type];
@@ -615,7 +615,7 @@ int nvidia_p2p_dma_map_pages(
 
     os_mem_set(peer_nvl, 0, sizeof(nv_linux_state_t));
 
-    peer_nvl->dev = peer;
+    peer_nvl->pci_dev = peer;
 
     peer_nv = NV_STATE_PTR(peer_nvl);
 
@@ -642,7 +642,7 @@ int nvidia_p2p_dma_map_pages(
     (*dma_mapping)->entries = page_count;
     (*dma_mapping)->dma_addresses = dma_addresses;
     (*dma_mapping)->private = priv;
-    (*dma_mapping)->dev = peer;
+    (*dma_mapping)->pci_dev = peer;
 
     /*
      * All success, it is safe to insert dma_mapping now.
@@ -714,7 +714,7 @@ int nvidia_p2p_dma_unmap_pages(
         return 0;
     }
 
-    WARN_ON(peer != dma_mapping->dev);
+    WARN_ON(peer != dma_mapping->pci_dev);
 
     BUG_ON((dma_mapping->page_size_type <= NVIDIA_P2P_PAGE_SIZE_4KB) ||
            (dma_mapping->page_size_type >= NVIDIA_P2P_PAGE_SIZE_COUNT));
@@ -869,7 +869,7 @@ int nvidia_p2p_get_rsync_registers(
 
         regs[index].ptr = ptr;
         regs[index].size = size;
-        regs[index].gpu = nvl->dev;
+        regs[index].gpu = nvl->pci_dev;
         regs[index].ibmnpu = ibmnpu;
         regs[index].cluster_id = 0;
         regs[index].socket_id = nv_get_ibmnpu_chip_id(nv);
